==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ChartSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescription } from "./ChartSortDescriptionDescription";
/**
 * @hidden
 */
export let ChartSortDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSortDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSortDescriptionDescriptionMetadata.a == null) {
                ChartSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSortDescriptionDescriptionMetadata.c(ChartSortDescriptionDescriptionMetadata.a);
            }
            if (a.j(ChartSortDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.y(ChartSortDescriptionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("SortDirection", "ExportedType:string:ListSortDirection");
            a.item("SortDirection@names", "Ascending;Descending");
        }
        static d(a) {
            ChartSortDescriptionDescriptionMetadata.b(a);
            a.aa("ChartSortDescription", () => new ChartSortDescriptionDescription());
            a.z("ChartSortDescription", ChartSortDescriptionDescriptionMetadata.a);
        }
    }
    ChartSortDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartSortDescriptionDescriptionMetadata, 'ChartSortDescriptionDescriptionMetadata');
    ChartSortDescriptionDescriptionMetadata.a = null;
    return ChartSortDescriptionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ChartSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescription } from "./ChartSortDescriptionDescription";
/**
 * @hidden
 */
export let ChartSortDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSortDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSortDescriptionDescriptionMetadata.a == null) {
                ChartSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSortDescriptionDescriptionMetadata.c(ChartSortDescriptionDescriptionMetadata.a);
            }
            if (a.k(ChartSortDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.aa(ChartSortDescriptionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("SortDirection", "ExportedType:string:ListSortDirection");
            a.item("SortDirection@names", "Ascending;Descending");
        }
        static d(a) {
            ChartSortDescriptionDescriptionMetadata.b(a);
            a.ac("ChartSortDescription", () => new ChartSortDescriptionDescription());
            a.ab("ChartSortDescription", ChartSortDescriptionDescriptionMetadata.a);
        }
    }
    ChartSortDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartSortDescriptionDescriptionMetadata, 'ChartSortDescriptionDescriptionMetadata');
    ChartSortDescriptionDescriptionMetadata.a = null;
    return ChartSortDescriptionDescriptionMetadata;
})();
